@@ -1,4 +1,4 @@
-use super::{super::OrderedVocabIter, Error, Pair, Word};
+use super::{super::OrderedVocabIter, trainer::BpeTrainer, Error, Pair, Word};
 use crate::tokenizer::{Model, Result, Token};
 use crate::utils::cache::{Cache, DEFAULT_CACHE_CAPACITY};
 use crate::utils::iter::ResultShunt;
@@ -189,15 +189,15 @@ pub struct BPE {
     cache: Option<Cache<String, Word>>,
     /// Dropout probability for merges. 0 = no dropout is the default. At 1.0, tokenization will
     /// perform no merges, so the result will just be characters.
-    pub(super) dropout: Option<f32>,
+    pub dropout: Option<f32>,
     /// The unknown token to be used when we encounter an unknown char
-    pub(super) unk_token: Option<String>,
+    pub unk_token: Option<String>,
     /// An optional prefix to use on any subword that exist only behind another one
-    pub(super) continuing_subword_prefix: Option<String>,
+    pub continuing_subword_prefix: Option<String>,
     /// An optional suffix to caracterize and end-of-word subword
-    pub(super) end_of_word_suffix: Option<String>,
+    pub end_of_word_suffix: Option<String>,
     /// Do multiple unk tokens get fused
-    pub(super) fuse_unk: bool,
+    pub fuse_unk: bool,
 }
 
 impl std::fmt::Debug for BPE {
@@ -318,8 +318,8 @@ impl BPE {
         }
     }
 
-    pub fn get_vocab(&self) -> &Vocab {
-        &self.vocab
+    pub fn get_vocab(&self) -> Vocab {
+        self.vocab.clone()
     }
 
     pub fn get_unk_token(&self) -> &Option<String> {
@@ -335,23 +335,29 @@ impl BPE {
         let mut word = Word::with_capacity(w.len());
         let mut unk: Option<(u32, usize)> = None;
         while let Some(i) = indices.next() {
-            let (s, byte_len) = if let Some(&end) = indices.peek() {
-                match (i, self.continuing_subword_prefix.as_ref()) {
-                    (0, Some(prefix)) => (
-                        Cow::Owned(format!("{}{}", prefix, &w[i..end])),
-                        (i..end).len(),
-                    ),
-                    _ => (Cow::Borrowed(&w[i..end]), (i..end).len()),
-                }
+            let end = indices.peek();
+            let is_first = i == 0;
+            let is_last = end.is_none();
+
+            let mut s = if let Some(e) = end {
+                Cow::Borrowed(&w[i..*e])
             } else {
-                (
-                    self.end_of_word_suffix
-                        .as_ref()
-                        .map(|suffix| format!("{}{}", &w[i..], suffix).into())
-                        .unwrap_or_else(|| Cow::Borrowed(&w[i..])),
-                    w[i..].len(),
-                )
+                Cow::Borrowed(&w[i..])
             };
+            let byte_len = s.len();
+
+            // Add the `continuing_subword_prefix` if relevant
+            if !is_first {
+                if let Some(ref prefix) = self.continuing_subword_prefix {
+                    s = format!("{}{}", prefix, s).into()
+                }
+            }
+            // Add the `end_of_word_suffix` if relevant
+            if is_last {
+                if let Some(ref suffix) = self.end_of_word_suffix {
+                    s = format!("{}{}", s, suffix).into()
+                }
+            }
 
             if let Some(id) = self.vocab.get(s.as_ref()) {
                 if let Some((unk_id, unk_len)) = unk {
@@ -415,8 +421,10 @@ impl BPE {
 }
 
 impl Model for BPE {
-    fn get_vocab(&self) -> &HashMap<String, u32> {
-        &self.vocab
+    type Trainer = BpeTrainer;
+
+    fn get_vocab(&self) -> HashMap<String, u32> {
+        self.vocab.clone()
     }
 
     fn get_vocab_size(&self) -> usize {
@@ -440,8 +448,8 @@ impl Model for BPE {
         self.vocab.get(token).copied()
     }
 
-    fn id_to_token(&self, id: u32) -> Option<&str> {
-        self.vocab_r.get(&id).map(String::as_ref)
+    fn id_to_token(&self, id: u32) -> Option<String> {
+        self.vocab_r.get(&id).cloned()
     }
 
     fn save(&self, folder: &Path, name: Option<&str>) -> Result<Vec<PathBuf>> {
@@ -487,6 +495,10 @@ impl Model for BPE {
 
         Ok(vec![vocab_path, merges_path])
     }
+
+    fn get_trainer(&self) -> BpeTrainer {
+        BpeTrainer::default()
+    }
 }
 
 #[cfg(test)]
@@ -678,17 +690,41 @@ mod tests {
             ("##b".to_string(), 1),
             ("##c".to_string(), 2),
             ("ab".to_string(), 3),
+            ("abc".to_string(), 4),
         ]
         .into_iter()
         .collect();
 
-        let merges = vec![("a".to_string(), "##b".to_string())];
+        let merges = vec![
+            ("a".to_string(), "##b".to_string()),
+            ("ab".to_string(), "##c".to_string()),
+        ];
 
-        BPE::builder()
+        let bpe = BPE::builder()
             .vocab_and_merges(vocab, merges)
+            .unk_token("[UNK]".to_string())
             .continuing_subword_prefix("##".to_string())
             .build()
             .unwrap();
+
+        let res = bpe.tokenize("ab");
+        assert_eq!(
+            res.unwrap(),
+            vec![Token {
+                id: 3,
+                value: "ab".to_string(),
+                offsets: (0, 2)
+            }]
+        );
+        let res = bpe.tokenize("abc");
+        assert_eq!(
+            res.unwrap(),
+            vec![Token {
+                id: 4,
+                value: "abc".to_string(),
+                offsets: (0, 3)
+            }]
+        );
     }
 
     #[test]
